@@ -1,140 +1,11 @@
 package DAIA;
-
-=head1 NAME
-
-DAIA - Document Availability Information API in Perl
-
-=cut
+{
+  $DAIA::VERSION = '0.35';
+}
+#ABSTRACT: Document Availability Information API
 
 use strict;
-our $VERSION = '0.31';
 
-=head1 DESCRIPTION
-
-The Document Availability Information API (DAIA) defines a data model with 
-serializations in JSON and XML to encode information about the current 
-availability of documents. See L<http://daia.sourceforge.net/> for more 
-information and the recent developer version. This package provides Perl 
-classes and functions to easily create and manage DAIA information. It can
-be used to implement DAIA servers, clients, and other programs that handle 
-availability information.
-
-For a detailed description what "availability" means in context of DAIA,
-see the L<DAIA specification|http://purl.org/NET/DAIA>. This implementation
-directly maps DAIA information objects to Perl objects, that all provide 
-some L<standard methods|/"DAIA OBJECTS">. You can also let the package 
-L<export functions|/"EXPORTED FUNCTIONS"> to handle DAIA data without 
-much object-orientation.
-
-In short the most important concepts of DAIA are:
-
-=over 4
-
-=item B<documents>
-
-An abstract document (work or edition). Implemented as L<DAIA::Document>.
-
-=item B<items>
-
-A particular copy of a document (physical or digital), that services
-can be provided with. Implemented as L<DAIA::Item>.
-
-=item B<availability status>
-
-A boolean value and a service that indicates I<for what> an item is 
-available or not available. Implemented as L<DAIA::Availability> with 
-the subclasses L<DAIA::Available> and L<DAIA::Unavailable>.
-
-=item B<responses>
-
-Information about the availability of a document with a timestamp. Responses
-are used to send and recieve DAIA data. Implemented as L<DAIA::Response>.
-
-=item
-
-=back 
-
-=head1 SYNOPSIS
-
-=head2 DAIA client
-
-  #!/usr/bin/perl
-  use DAIA;
-
-  $daia = DAIA::parse( $url );          # parse from URL
-  $daia = DAIA::parse( file => $file ); # parse from File
-
-  # parse from string
-  use Encode; # if incoming data is unencoded UTF-8
-  $data = Encode::decode_utf8( $data ); # skip this if $data is just Unicode
-  $daia = DAIA::parse( data => $string );
-
-This package also includes and installs the command line and CGI client
-L<daia> to fetch, validate and convert DAIA data. See also the C<clients>
-directory for an XML Schema of DAIA/XML and an XSLT script to transform it
-to HTML.
-
-=head2 DAIA server
-
-First an example of a DAIA server as CGI script. You need to implement all
-C<get_...> methods to return meaningful values. Some more hints how
-to run a DAIA Server below under under L</DAIA Server hints>.
-
-  #!/usr/bin/perl
-  use DAIA;
-  use CGI; # or some other CGI module, for instance CGI::Minimal
-  use utf8; # if source code containts UTF-8
-
-  my $r = response( institution => {
-          href    => "http://example.com/homepage.of.institution",
-          content => "Name of the Institution" 
-  } );
-
-  my $id = CGI->new->param('id');
-  $r->addMessage("en" => "Not an URI: $id", errno => 1 )
-      unless DAIA::is_uri($id);
-  my @holdings = get_holding_information($id);  # YOU need to implement this!
-
-  if ( @holdings ) {
-      my $doc = document( id => $id, href => "http://example.com/docs/$id" );
-      foreach my $h ( @holdings ) {
-          my $item = item();
-
-          my %sto = get_holding_storage( $h );
-          $item->storage( id => $sto{id}, href => $sto{href}, $sto{name} );
-
-          my $label = get_holding_label( $h );
-          $item->label( $label );
-
-          my $url = get_holding_url( $h );
-          $item->href( $url );
-
-          # add availability services
-          my @services;
-
-          if ( get_holding_is_here( $h ) ) {
-              push @services, available('presentation'), available('loan');
-          } elsif( get_holding_is_not_here( $h ) ) {
-              push @services, # expected to be back in 5 days
-              unavailable( 'presentation', expected => 'P5D' ),
-              unavailable( 'loan', expected => 'P5D' );
-          } else {
-             #  more cases (depending on the complexity of you application)
-          }
-          $item->add( @services );
-      }
-      $r->document( $doc );
-  } else {
-      $r->addMessage( "en" => "No holding information found for id $id" );
-  }
-
-  $r->serve( xslt => "http://path.to/daia.xsl" );
-
-In order to get your script run as CGI, you may have to enable CGI with 
-C<Options +ExecCGI> and C<AddHandler cgi-script .pl> in your Apache
-configuration or C<.htaccess>. 
-
-=cut
 
 use base 'Exporter';
 our %EXPORT_TAGS = (
@@ -158,6 +29,7 @@ use DAIA::Availability;
 use DAIA::Available;
 use DAIA::Unavailable;
 use DAIA::Message;
+use DAIA::Error;
 use DAIA::Entity;
 use DAIA::Institution;
 use DAIA::Department;
@@ -166,44 +38,6 @@ use DAIA::Limitation;
 
 use Data::Validate::URI qw(is_uri);
 
-=head1 EXPORTED FUNCTIONS
-
-If you prefer function calls in favor of constructor calls, this package  
-providesfunctions for each DAIA class constructor. The functions are named  
-by the object that they create but in lowercase - for instance C<response> 
-for the L<DAIA::Response> object. The functions can be exported in groups. 
-To disable exporting of the functions include DAIA like this: 
-
-  use DAIA qw();      # do not export any functions
-  use DAIA qw(serve); # only export function 'serve'
-
-By default all functions are exported (group :all) which adds 13 functions 
-to the default namespace! Alternatively you can specify the following groups:
-
-=over 4
-
-=item C<:core>
-
-Includes the functions C<response> (L<DAIA::Response>),
-C<document> (L<DAIA::Document>), 
-C<item> (L<DAIA::Item>),
-C<available> (L<DAIA::Available>), 
-C<unavailable> (L<DAIA::Unavailable>), and
-C<availability> (L<DAIA::Availability>)
-
-=item C<:entities>
-
-Includes the functions C<institution> (L<DAIA::Institution>),
-C<department> (L<DAIA::department>),
-C<storage> (L<DAIA::Storage>), and
-C<limitation> (L<DAIA::Limitation>)
-
-=back
-
-The functions C<message>, C<error> and C<serve> are also exported by default.
-See L<DAIA::Message> for the parameters of C<message> or C<error>.
-
-=cut
 
 sub response     { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Response->new( @_ ) }
 sub document     { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Document->new( @_ ) }
@@ -219,104 +53,17 @@ sub limitation   { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::L
 
 sub error { 
     local $Carp::CarpLevel = $Carp::CarpLevel + 1; 
-    my $errno = @_ ? shift : 0;
-    return DAIA::Message->new( @_ ? (@_, errno => $errno) : (errno => $errno) );
+    #my $errno = @_ ? shift : 0;
+    #return DAIA::Message->new( @_ ? (@_, errno => $errno) : (errno => $errno) );
+    return DAIA::Error->new( @_ );
 }
 
-=head2 serve( [ [ format => ] $format ] [ %options ] )
-
-Calls the method method C<serve> of L<DAIA::Response> or another DAIA object
-to serialize and send a response to STDOUT with appropriate HTTP headers. 
-You can call it this way:
-
-  serve( $response, @additionlArgs );  # as function
-  $response->serve( @additionlArgs );  # as method
-
-=cut
 
 sub serve {
     local $Carp::CarpLevel = $Carp::CarpLevel + 1; 
     shift->serve( @_ );
 }
 
-=head1 ADDITIONAL FUNCTIONS
-
-The following functions are not exported but you can call both them as 
-function and as method:
-
-  DAIA->parse_xml( $xml );
-  DAIA::parse_xml( $xml );
-
-On request you can export the functions C<guess> and C<parse>.
-
-=head2 parse_xml( $xml )
-
-Parse DAIA/XML from a file or string. The first parameter must be a 
-filename, a string of XML, or a L<IO::Handle> object.
-
-Parsing is more lax then the specification so it silently ignores 
-elements and attributes in foreign namespaces. Returns either a DAIA 
-object or croaks on uncoverable errors.
-
-=cut
-
-sub parse_xml {
-    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
-    DAIA::parse( shift, format => 'xml', @_ );
-}
-
-=head2 parse_json( $json )
-
-Parse DAIA/JSON from a file or string. The first parameter must be a 
-filename, a string of XML, or a L<IO::Handle> object.
-
-=cut
-
-sub parse_json {
-    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );    
-    DAIA::parse( shift, format => 'json' );
-}
-
-=head2 parse ( $from [ %parameters ] )
-
-Parse DAIA/XML or DAIA/JSON from a file or string. You can specify the source
-as filename, string, or L<IO::Handle> object as first parameter or with the
-named C<from> parameter. Alternatively you can either pass a filename or URL with
-parameter C<file> or a string with parameter C<data>. If C<from> or C<file> is an
-URL, its content will be fetched via HTTP. The C<format> parameter (C<json> or C<xml>)
-is required unless the format can be detected automatically the following way:
-
-=over
-
-=item *
-
-A scalar starting with C<E<lt>> and ending with C<E<gt>> is parsed as DAIA/XML.
-
-=item *
-
-A scalar starting with C<{> and ending with C<}> is parsed as DAIA/JSON.
-
-=item *
-
-A scalar starting with C<http://> or C<https://> is used to fetch data via HTTP.
-The resulting data is interpreted as DAIA/XML or DAIA/JSON.
-
-=item *
-
-A scalar ending with C<.json> is parsed as DAIA/JSON file.
-
-=item *
-
-A scalar ending with C<.xml> is is parsed as DAIA/XML file.
-
-=back
-
-Normally this function or method returns a single DAIA object. When parsing 
-DAIA/XML it may also return a list of objects. It is recommended to always
-expect a list unless you are absolutely sure that the result of parsing will
-be a single DAIA object.
-
-=cut
 
 sub parse {
     shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
@@ -424,14 +171,21 @@ sub parse {
     return wantarray ? @objects : $objects[0];
 }
 
-=head2 guess ( $string )
 
-Guess serialization format (DAIA/JSON or DAIA/XML) and return C<json>, C<xml> 
-or the empty string.
+sub parse_xml {
+    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
+    DAIA::parse( shift, format => 'xml', @_ );
+}
+
+
+sub parse_json {
+    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );    
+    DAIA::parse( shift, format => 'json' );
+}
 
-=cut
 
 sub guess {
+    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );    
     my $data = shift;
     return '' unless $data;
     return 'xml' if $data =~ m{^\s*\<.*?\>\s*$}s;
@@ -439,43 +193,10 @@ sub guess {
     return '';
 }
 
-=head2 is_uri ( $value )
-
-Checks whether the value is a well-formed URI. This function is imported from
-L<Data::Validate::URI> into the namespace of this package as C<DAIA::is_uri>.
-On request the function can be exported into the default namespace.
-
-=head1 DAIA OBJECTS
-
-All objects (documents, items, availability, status, institutions, departments,
-limitations, storages, messages, errors) are implemented as subclass of
-L<DAIA::Object>. Therefore, all objects have the following methods:
-
-=over 4
-
-=item C<new>
-
-Constructs a new object.
-
-=item C<add>
-
-Adds typed properties.
-
-=item C<xml>, C<struct>, C<json>, C<rdfhash>
-
-Returns several serialization forms.
-
-=item C<serve>
-
-Serialize the object and send it to STDOUT with the appropriate HTTP headers.
-
-=back
-
-=cut
 
 #### internal methods (subject to be changed)
 
-my $NSEXPDAIA = qr/{http:\/\/(ws.gbv.de|purl.org\/ontology)\/daia\/}(.*)/;
+my $NSEXPDAIA    = qr/{http:\/\/(ws.gbv.de|purl.org\/ontology)\/daia\/}(.*)/;
 
 # =head1 daia_xml_roots ( $xml )
 #
@@ -504,7 +225,7 @@ sub daia_xml_roots {
                     $v = [$v] unless UNIVERSAL::isa($v,'ARRAY');
                     if ($out->{$k}) {
                         push @$v, (UNIVERSAL::isa($out->{$k},'ARRAY') ? 
-                                   @{$out->{$k}} : $out->{$k});
+                                @{$out->{$k}} : $out->{$k});
                     }
                     # filter out scalars
                     @$v = grep {ref($_)} @$v unless $k =~ $NSEXPDAIA;
@@ -549,6 +270,316 @@ sub _filter_xml {
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+DAIA - Document Availability Information API
+
+=head1 VERSION
+
+version 0.35
+
+=head1 SYNOPSIS
+
+This package includes and installs the client program C<daia> to fetch,
+validate and convert DAIA data (both command line and CGI). See also the
+C<clients> directory for an XML Schema of DAIA/XML and an XSLT script to 
+transform DAIA/XML to HTML.
+
+=head2 A DAIA client
+
+  use DAIA;  # or: use DAIA qw(parse);
+
+  $daia = DAIA::parse( $url );
+  $daia = DAIA::parse( file => $file );
+  $daia = DAIA::parse( data => $string ); # $string must be Unicode
+
+=head2 A DAIA server
+
+  use DAIA;
+
+  use CGI;
+  my $id = CGI->new->param('id');
+
+  my $r = response( institution => {
+      href    => "http://example.com/your-institution's-homepage",
+      content => "Your institution's name" 
+  } );
+
+  $r->addMessage("en" => "Not an URI: $id", errno => 1 )
+      unless DAIA::is_uri($id);
+
+  my @holdings = get_holding_information($id);      # your custom method
+
+  if ( @holdings ) {
+      my $doc = document( id => $id, href => "http://example.com/docs/$id" );
+      foreach my $h ( @holdings ) {
+          my $item = item();
+
+          my %stor = get_holding_storage( $h );     # your custom method
+          $item->storage( id => $stor{id}, href => $stor{href}, $stor{name} );
+
+          $item->label( get_holding_label( $h ) );  # your custom method
+          $item->href( get_holding_url( $h ) );     # your custom method
+
+          # add availability services
+          my @services;
+
+          if ( get_holding_is_here( $h ) ) {          # your custom method
+              push @services, available('presentation'), available('loan');
+          } elsif( get_holding_is_not_here( $h ) ) {  # your custom method
+              push @services, # expected to be back in 5 days
+              unavailable( 'presentation', expected => 'P5D' ),
+              unavailable( 'loan', expected => 'P5D' );
+          } else {
+             #  more cases (depending on the complexity of you application)
+          }
+          $item->add( @services );
+      }
+      $r->document( $doc );
+  } else {
+      $r->addMessage( "en" => "No holding information found for id $id" );
+  }
+
+  $r->serve( xslt => "http://path.to/daia.xsl" );
+
+To run your script as CGI, you may have to enable CGI with C<Options +ExecCGI>
+and C<AddHandler cgi-script .pl> in your Apache configuration or in C<.htaccess>.
+Some more hints are L<listed below|/"DAIA Server hints">.
+
+=head1 DESCRIPTION
+
+The Document Availability Information API (DAIA) defines a model of information
+about the current availability of documents, for instance in a library. DAIA
+includes a specification of serializations in JSON, XML, and RDF. More details
+can be found in the DAIA specification at L<http://purl.org/NET/DAIA> and at
+the developer repository at L<http://daia.sourceforge.net/>.
+
+This package provides Perl classes and functions to easily create and manage
+DAIA information in any form. It can be used to quickly implement DAIA servers,
+clients, and other programs that handle availability information of documents.
+
+The most important concepts of the DAIA model are:
+
+=over 4
+
+=item B<documents>
+
+These abstract works or editions are implemented as objects of class
+L<DAIA::Document>.
+
+=item B<items>
+
+These particular copies of documents (physical or digital) are
+implemented as objects of class L<DAIA::Item>.
+
+=item B<services> and C<availability status>
+
+A service is something that can be provided with an item. A particular
+service has a particular availability status, that is implemented as
+object of class L<DAIA::Available> or L<DAIA::Unavailable>.
+
+=item B<availability status>
+
+A boolean value and a service that indicates I<for what> an item is 
+available or not available. Implemented as L<DAIA::Availability> with 
+the subclasses L<DAIA::Available> and L<DAIA::Unavailable>.
+
+=item B<responses>
+
+A response contains information about the availability of documents at 
+a given point in time, optionally at some specific institution. It is
+implemented as object of class L<DAIA::Response>.
+
+=back
+
+Additional L<DAIA objects|/"DAIA OBJECTS"> include B<institutions>
+(L<DAIA::Institution>), B<departments> (L<DAIA::Department>), 
+storages (L<DAIA::Storage>), messages (L<DAIA::Message>), and 
+errors (L<DAIA::Message>). All these objects provide standard methods
+for creation, modification, and serialization. This package also
+L<exports functions|/"FUNCTIONS"> as shorthand for object constructors,
+for instance the following two result in the same:
+
+  item( id => $id );
+  DAIA::Item->new( id => $id );
+
+=head1 FUNCTIONS
+
+By default constructor functions are exported for all objects.
+To disable exporting, include DAIA like this:
+
+  use DAIA qw();       # do not export any functions
+  use DAIA qw(serve);  # only export function 'serve'
+  use DAIA qw(:core);  # only export core functions
+
+You can select two groups, both are exported by default:
+
+=over 4
+
+=item C<:core>
+
+C<response>, C<document>, C<item>, C<available>, C<unavailable>, 
+C<availability>
+
+=item C<:entities>
+
+C<institution>, C<department>, C<storage>, C<limitation>
+
+=back
+
+Additional functions are C<message> and C<error> as object constructors,
+and C<serve>. The other functions below are not exported by default.
+You can call them as method or as function, for instance:
+
+  DAIA->parse_xml( $xml );
+  DAIA::parse_xml( $xml );
+
+=head2 serve( [ [ format => ] $format ] [ %options ] )
+
+Calls the method method C<serve> of L<DAIA::Response> or another DAIA object
+to serialize and send a response to STDOUT with appropriate HTTP headers. 
+You can call it this way:
+
+  serve( $response, @additionlArgs );  # as function
+  $response->serve( @additionlArgs );  # as method
+
+=head2 parse ( $from [ %parameters ] )
+
+Parse DAIA/XML or DAIA/JSON from a file or string. You can specify the source
+as filename, string, or L<IO::Handle> object as first parameter or with the
+named C<from> parameter. Alternatively you can either pass a filename or URL with
+parameter C<file> or a string with parameter C<data>. If C<from> or C<file> is an
+URL, its content will be fetched via HTTP. The C<format> parameter (C<json> or C<xml>)
+is required unless the format can be detected automatically the following way:
+
+=over
+
+=item *
+
+A scalar starting with C<E<lt>> and ending with C<E<gt>> is parsed as DAIA/XML.
+
+=item *
+
+A scalar starting with C<{> and ending with C<}> is parsed as DAIA/JSON.
+
+=item *
+
+A scalar ending with C<.xml> is is parsed as DAIA/XML file.
+
+=item *
+
+A scalar ending with C<.json> is parsed as DAIA/JSON file.
+
+=item *
+
+A scalar starting with C<http://> or C<https://> is used to fetch data via HTTP.
+The resulting data is interpreted again as DAIA/XML or DAIA/JSON.
+
+=back
+
+Normally this function or method returns a single DAIA object. When parsing 
+DAIA/XML it may also return a list of objects. It is recommended to always
+expect a list unless you are absolutely sure that the result of parsing will
+be a single DAIA object.
+
+=head2 parse_xml( $xml )
+
+Parse DAIA/XML from a file or string. The first parameter must be a 
+filename, a string of XML, or a L<IO::Handle> object.
+
+Parsing is more lax then the specification so it silently ignores 
+elements and attributes in foreign namespaces. Returns either a DAIA 
+object or croaks on uncoverable errors.
+
+=head2 parse_json( $json )
+
+Parse DAIA/JSON from a file or string. The first parameter must be a 
+filename, a string of XML, or a L<IO::Handle> object.
+
+=head2 guess ( $string )
+
+Guess serialization format (DAIA/JSON or DAIA/XML) and return C<json>, C<xml> 
+or the empty string.
+
+=head2 is_uri ( $value )
+
+Checks whether the value is a well-formed URI. This function is imported from
+L<Data::Validate::URI> into the namespace of this package as C<DAIA::is_uri>.
+On request the function can be exported into the default namespace.
+
+=head1 DAIA OBJECTS
+
+All objects (documents, items, availability status, institutions, departments,
+limitations, storages, messages, errors) are implemented as subclass of
+L<DAIA::Object>, which is just another Perl meta-class framework.
+All objects have the following methods:
+
+=head2 item
+
+Constructs a new object.
+
+=head2 add
+
+Adds typed properties.
+
+=head2 xml, struct, json, rdfhash
+
+Returns several serialization forms.
+
+=head2 serve ( [ [ format => ] $format | [ cgi => $CGI ] ] [ %more_options ] )
+
+Serialize the object and send it to STDOUT (or to another stream) with the 
+appropriate HTTP headers. This method is available for all DAIA objects but
+mostly used to serve a L<DAIA::Response>. The serialized object must already
+be encoded in UTF-8 (but it can contain Unicode strings).
+
+The serialization format can be specified with the first parameter as
+C<format> string (C<json> or C<xml>) or C<cgi> object. If no format is
+given, it is searched for in the L<CGI> query parameters. The default 
+format is C<xml>. Other possible options are:
+
+=over
+
+=item header
+
+Print HTTP headers (default). Use C<header =E<gt> 0> to disable headers.
+
+=head xmlheader
+
+Print the XML header of XML format is used. Enabled by default.
+
+=item xslt
+
+Add a link to the given XSLT stylesheet if XML format is used.
+
+=item pi
+
+Add one or more processing instructions if XML format is used.
+
+=item callback
+
+Add this JavaScript callback function in JSON format. If no callback
+function is specified, it is searched for in the CGI query parameters.
+You can disable callback support by setting C<callback =E<gt> undef>.
+
+=item to
+
+Serialize to a given stream (L<IO::Handle>, GLOB, or string reference)
+instead of STDOUT. You may also want to set C<exitif> if you use
+this option.
+
+=item exitif
+
+By setting this method to a true value you make it to exit the program.
+you provide a method, the method is called and the script exits if only
+if the return value is true.
+
+=back
+
 =head1 DAIA Server hints
 
 DAIA server scripts can be tested on command line by providing HTTP
@@ -563,67 +594,55 @@ For FastCGI you need to install L<FCGI> and set the CGI handler to
 L<AddHandler fcgid-script .pl> in C<.htaccess>. Your DAIA server must
 consist of an initialization section and a response loop:
 
-  #!/usr/bin/perl
-  use DAIA;
-  use CGI::Fast;
+    #!/usr/bin/perl
+    use DAIA;
+    use CGI::Fast;
+    
+    # ...initialization section, which is executed only once ...
+    
+    while (my $q = new CGI::Fast) { # response loop
+        my $id = $q->param('id');
 
-  # ...initialization section, which is executed only once ...
+        # ... create response ...
 
-  while (my $q = new CGI::Fast) { # response loop
-      my $id = $q->param('id');
-
-      # ... create response ...
-     
-      $response->serve( cgi => $q, exitif => 0 );
-  }
+        $response->serve( cgi => $q, exitif => 0 );
+    }
 
 The C<serve> methods needs a C<cgi> or C<format> parameter and it is
 been told not to exit the script. It is recommended to check every
 given timespan whether the script has been modified and restart in
 this case:
 
-  #!/usr/bin/perl
-  use DAIA;
-  use CGI::Fast;
+    #!/usr/bin/perl
+    use DAIA;
+    use CGI::Fast;
+    
+    my $started = time;
+    my $thisscript = $0;
+    my $lastmod = (stat($thisscript))[9] # mtime;
+    
+    sub restart {
+        return 0 if time - $started < 10; # check every 10 seconds
+            return 1 if (stat($thisscript))[9] > $lastmod;
+    }
+    
+    while (my $q = new CGI::Fast) { # response loop
 
-  my $started = time;
-  my $thisscript = $0;
-  my $lastmod = (stat($thisscript))[9] # mtime;
+        # ... create response ...
 
-  sub restart {
-      return 0 if time - $started < 10; # check every 10 seconds
-      return 1 if (stat($thisscript))[9] > $lastmod;
-  }
-
-  while (my $q = new CGI::Fast) { # response loop
-
-      # ... create response ...
-
-      $response->serve( $q, exitif => \&restart } );
-  }
-
-
-=head1 SEE ALSO
-
-Please report bugs and feature requests via L<https://rt.cpan.org/Public/Dist/Display.html?Name=DAIA>.
-The classes of this package are implemented using L<DAIA::Object> which is just another
-Perl meta-class framework.
-
-The current developer version of this package together with more DAIA
-implementations in other programming languages is availabe in a project
-at Sourceforge: L<http://sourceforge.net/projects/daia/>. Feel free to
-contribute!
-
-A specification of DAIA can be found at L<http://purl.org/NET/DAIA>.
+        $response->serve( $q, exitif => \&restart } );
+    }
 
 =head1 AUTHOR
 
-Jakob Voss C<< <jakob.voss@gbv.de> >>
+Jakob Voss
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+This software is copyright (c) 2011 by Jakob Voss.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.8.8 or, at
-your option, any later version of Perl 5 you may have available.
