@@ -1,14 +1,77 @@
 package DAIA::Message;
-
-=head1 NAME
-
-DAIA::Message - An optional information text or error message
-
-=cut
+{
+  $DAIA::Message::VERSION = '0.35';
+}
+#ABSTRACT: An optional information text
 
 use strict;
 use base 'DAIA::Object';
-our $VERSION = '0.27';
+
+
+our $DEFAULT_LANG = 'en';
+
+our %PROPERTIES = (
+    content => { 
+        default => '', 
+        filter => sub { "$_[0]" }  # stringify everything
+    },
+    lang => { 
+        default => sub { $DEFAULT_LANG },
+        filter => sub { 
+            is_language_tag("$_[0]") ? lc("$_[0]") : undef;
+        },
+    },
+    errno => {
+        default => undef,
+        fixed   => undef,
+    }
+);
+
+# called by the constructor
+sub _buildargs {
+    my $self = shift;
+    if ( @_ % 2 ) {  # content as first parameter
+        my ($content, %p) = @_;
+        if ( @_ == 3 and not defined $PROPERTIES{$_[1]} ) {
+            return ( lang => $_[0], content => $_[1] );
+        } else {
+            return ( content => $content, %p );
+        }
+    } elsif ( defined $_[0] and not defined $PROPERTIES{$_[0]} and is_language_tag($_[0]) ) {
+        my ($lang, $content, %p) = @_;
+        return ( lang => $lang, content => $content, %p );
+    } else {
+        return @_;
+    }
+
+    return @_;
+}
+
+sub rdfhash {
+    my $self = shift;
+    my $rdf = { type => 'literal', value => $self->{content} };
+    $rdf->{lang} = $self->{lang} if $self->{lang};
+    return $rdf;
+}
+
+
+sub is_language_tag {
+    my($tag) = lc($_[0]);
+    return $tag =~ /^[a-z]{1,8}(-[a-z0-9]{1,8})*$/;
+}
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+DAIA::Message - An optional information text
+
+=head1 VERSION
+
+version 0.35
 
 =head1 DESCRIPTION
 
@@ -31,7 +94,7 @@ C<$DAIA::Message::DEFAULT_LANG> and set to C<'en'>.
 
 =item errno
 
-An integer value error code. By default a message has no error code.
+This property is always C<undef> no matter what you set it to.
 
 =back
 
@@ -42,14 +105,9 @@ The C<message> function is a shortcut for the DAIA::Message constructor:
 
 The constructor understands several abbreviated ways to define a message:
 
-  $msg = message( $content [, lang => $lang ] [, errno => $errno ] )
-  $msg = message( $lang => $content [, errno => $errno ] )
-  $msg = message( $lang => $content [, $errno ] )
-
-The value C<undef> as error code is ignored on construction. You can undefine
-an error code by explicitely setting it to C<undef>.
-
-  $msg->errno( undef );
+  $msg = message( $content [, lang => $lang ] )
+  $msg = message( $lang => $content )
+  $msg = message( $lang => $content )
 
 To set or get all messages of an object, you use the C<messages> accessor.
 You can pass an array reference or an array:
@@ -68,55 +126,6 @@ To append a message you can use the C<add> or the C<addMessage> method:
 
   $document += $msg;              # same as $document->add( $msg );
 
-In addition to the C<message> function there is the C<error> function to quickly
-construct error messages. The first parameter is always treated as error number:
-
-  error() # errno = 0
-  error( $errno [, $lang => $content ] ) 
-  error( $errno, $content [, lang => $lang ] )
-
-=cut
-
-our $DEFAULT_LANG = 'en';
-
-our %PROPERTIES = (
-    content => { 
-        default => '', 
-        filter => sub { "$_[0]" }  # stringify everything
-    },
-    lang => { 
-        default => sub { $DEFAULT_LANG },
-        filter => sub { 
-            is_language_tag("$_[0]") ? lc("$_[0]") : undef;
-        },
-    },
-    errno => {                                           
-        filter => sub { 
-            $_[0] =~ m/^-?\d+$/ ? $_[0] : undef  
-        } 
-    },
-);
-
-# called by the constructor
-sub _buildargs {
-    my $self = shift;
-    if ( @_ % 2 ) {  # content as first parameter
-        my ($content, %p) = @_;
-        if ( @_ == 3 and not defined $PROPERTIES{$_[1]} ) {
-            return ( lang => $_[0], content => $_[1], errno => $_[2] );
-        } else {
-            return ( content => $content, %p );
-        }
-    } elsif ( defined $_[0] and not defined $PROPERTIES{$_[0]} and is_language_tag($_[0]) ) {
-        my ($lang, $content, %p) = @_;
-        return ( lang => $lang, content => $content, %p );
-    } else {
-        return @_;
-    }
-
-    return @_;
-}
-
 =head1 FUNCTIONS
 
 =head2 is_language_tag ( $tag )
@@ -125,23 +134,16 @@ Returns whether $tag is a formally valid language tag. The regular expression
 follows XML Schema type C<xs:language> instead of RFC 3066. For true RFC 3066 
 support have a look at L<I18N::LangTags>.
 
-=cut
-
-sub is_language_tag {
-    my($tag) = lc($_[0]);
-    return $tag =~ /^[a-z]{1,8}(-[a-z0-9]{1,8})*$/;
-}
-
-1;
-
 =head1 AUTHOR
 
-Jakob Voss C<< <jakob.voss@gbv.de> >>
+Jakob Voss
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+This software is copyright (c) 2011 by Jakob Voss.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.8.8 or, at
-your option, any later version of Perl 5 you may have available.
