@@ -1,15 +1,125 @@
 package DAIA::Response;
+{
+  $DAIA::Response::VERSION = '0.35';
+}
+#ABSTRACT: DAIA information root element
+
+use strict;
+use base 'DAIA::Object';
+
+use POSIX qw(strftime);
+
+
+our %PROPERTIES = (
+    version => {
+        default   => '0.5', 
+        filter    => sub { '0.5' }
+    },
+    timestamp => {
+        default   => sub { strftime("%Y-%m-%dT%H:%M:%SZ", gmtime); },
+        filter    => sub { $_[0] }, # TODO: check format 
+    },
+    message => $DAIA::Object::COMMON_PROPERTIES{message},
+    error   => $DAIA::Object::COMMON_PROPERTIES{error},
+    institution => { 
+        type => 'DAIA::Institution',
+    },
+    document => { 
+        type => 'DAIA::Document',
+        repeatable => 1
+    },
+);
+
+1;
+
+
+sub rdfhash {
+    my $self = shift;
+
+    my $me = {
+        'http://www.w3.org/1999/02/22-rdf-syntax-ns#type' => [{
+            type => 'uri', value => 'http://purl.org/ontology/daia/Response'
+        }]
+    };
+    $me->{'http://purl.org/ontology/daia/timestamp'} = [{
+            type => 'literal', value => $self->{timestamp},
+            datatype => 'http://www.w3c.org/2001/XMLSchema#dateTime'
+    }];# if $self->{timestamp};
+
+    $me->{'http://purl.org/dc/terms/description'} = [
+        map { $_->rdfhash } @{$self->{message}}
+    ] if $self->{message};
+
+    my $rdf = { $self->rdfuri => $me };
+    my $inst = $self->{institution};
+    my @doc  = @{$self->{document}} if $self->{document};
+
+    my @see = grep { defined $_ } $inst, @doc;
+    foreach my $s (@see) {
+        my $r = $s->rdfhash; # TODO: pass (institution => $inst->rdfuri)
+        $rdf->{$_} = $r->{$_} for keys %$r;
+    }
+
+    $me->{'http://www.w3.org/2000/01/rdf-schema#seeAlso'} = [
+        map { { type => 'uri', value => $_->rdfuri } } @see
+    ] if @see;
+
+    foreach my $doc (@doc) {
+        $rdf->{ $doc->rdfuri }->{'http://purl.org/ontology/daia/collectedBy'} = [{
+            type => "uri", value => $inst->rdfuri
+        }];
+    }
+
+    # TODO: add connections
+    # department <- subOrgOf / parOf institution
+    # service <- providedBy institution
+    
+    # # item <- heldBy
+    # TODO: if no inst given, try to use department instead
+    if ($self->document and $self->institution) {
+        my @items = map { $_->item ? @{$_->{item}} : () } @{$self->{document}};
+        my $by = $self->{institution}->rdfuri;
+        $by = { value => $by, type => ($by =~ /^_:/) ? 'bnode' : 'uri' };
+        foreach my $item (@items) {
+            $rdf->{ $item->rdfuri }->{'http://purl.org/ontology/daia/heldBy'} ||= [$by];
+        }
+    }
+
+    # delete $rdf->{ $self->rdfuri };
+
+    return $rdf;
+}
+
+
+sub check_valid_id {
+    my $self = shift;
+    my $id = shift; # TODO: take from CGI object, if not given
+
+    if ( ! defined $id ) {
+        $self->addMessage( "en" => "please provide a document id!", errno => 1 );
+    } elsif ( ! DAIA::is_uri( $id ) ) {
+        $id = " $id";
+        $id = (substr($id,0,32) . '...') if (length($id) > 32);
+        $self->addMessage( "en" => "document id$id is no valid URI!", errno => 2 );
+    } else {
+        return $id;
+    }
+
+    return undef;
+}
+
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
 DAIA::Response - DAIA information root element
 
-=cut
+=head1 VERSION
 
-use strict;
-use base 'DAIA::Object';
-our $VERSION = '0.28';
-use POSIX qw(strftime);
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -56,29 +166,6 @@ C<xs:dateTime> and is set to the current date and time on initialization.
 The additional read-only attribute B<version> gives the current version of
 DAIA format.
 
-=cut
-
-our %PROPERTIES = (
-    version => {
-        default => '0.5', 
-        filter => sub { '0.5' }
-    },
-    timestamp => {
-        default => sub { strftime("%Y-%m-%dT%H:%M:%SZ", gmtime); },
-        filter => sub { $_[0] } # TODO: check format 
-    },
-    message => $DAIA::Object::COMMON_PROPERTIES{message},
-    institution => { 
-        type => 'DAIA::Institution',
-    },
-    document => { 
-        type => 'DAIA::Document',
-        repeatable => 1
-    },
-);
-
-1;
-
 =head1 METHODS
 
 DAIA::Response provides the default methods of L<DAIA::Object> and accessor 
@@ -100,33 +187,16 @@ Check whether a valid identifier has been provided. If not, this methods
 appends an error message ("please provide a document id" or "document id
 ... is no valid URI") and returns undef.
 
-=cut
-
-sub check_valid_id {
-    my $self = shift;
-    my $id = shift; # TODO: take from CGI object, if not given
-
-    if ( ! defined $id ) {
-        $self->addMessage( "en" => "please provide a document id!", errno => 1 );
-    } elsif ( ! DAIA::is_uri( $id ) ) {
-        $id = " $id";
-        $id = (substr($id,0,32) . '...') if (length($id) > 32);
-        $self->addMessage( "en" => "document id$id is no valid URI!", errno => 2 );
-    } else {
-        return $id;
-    }
-
-    return undef;
-}
-
 =head1 AUTHOR
 
-Jakob Voss C<< <jakob.voss@gbv.de> >>
+Jakob Voss
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+This software is copyright (c) 2011 by Jakob Voss.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.8.8 or, at
-your option, any later version of Perl 5 you may have available.
