@@ -1,9 +1,48 @@
 package DAIA::Unavailable;
+{
+  $DAIA::Unavailable::VERSION = '0.35';
+}
+#ABSTRACT: Information about a service that is currently unavailable
+
+
+use strict;
+use base 'DAIA::Availability';
+
+use DateTime;
+
+
+our %PROPERTIES = (
+    %DAIA::Availability::PROPERTIES,
+    queue => { 
+        filter => sub { return $_[0] =~ /^[0-9]+$/ ? $_[0] : undef },
+    },
+    expected => { 
+        filter => sub { # TODO: move this to function in DAIA::Availability (?)
+            return 'unknown' if lc("$_[0]") eq 'unknown';
+            my $exp = $_[0];
+            if ($exp =~ /^P/ or UNIVERSAL::isa( $exp, 'DateTime::Duration' )) {
+                my $span = DAIA::Availability::parse_duration( $exp );
+                my $now = DateTime->from_epoch( epoch => time() );
+                $exp = $now->add_duration( $span );
+            }
+            return DAIA::Availability::date_or_datetime( $exp );
+        },
+    },
+);
+
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
 DAIA::Unavailable - Information about a service that is currently unavailable
 
+=head1 VERSION
+
+version 0.35
+
 =head1 DESCRIPTION
 
 This class models a service that is (currently or in general) not available. 
@@ -12,14 +51,6 @@ examples. In addition an instance of this class can have the properties
 C<expected> and C<queue>. Obviously the C<status> property of a
 C<DAIA::Unavailable> object is always C<0>.
 
-=cut
-
-use strict;
-use base 'DAIA::Availability';
-our $VERSION = '0.28';
-
-use DateTime;
-
 =head1 PROPERTIES
 
 =over
@@ -54,37 +85,16 @@ probably won't be available in the future.
 
 =back
 
-=cut
-
-our %PROPERTIES = (
-    %DAIA::Availability::PROPERTIES,
-    queue => { 
-        filter => sub { return $_[0] =~ /^[0-9]+$/ ? $_[0] : undef }
-    },
-    expected => { 
-        filter => sub { # TODO: move this to function in DAIA::Availability (?)
-            return 'unknown' if lc("$_[0]") eq 'unknown';
-            my $exp = $_[0];
-            if ($exp =~ /^P/ or UNIVERSAL::isa( $exp, 'DateTime::Duration' )) {
-                my $span = DAIA::Availability::parse_duration( $exp );
-                my $now = DateTime->from_epoch( epoch => time() );
-                $exp = $now->add_duration( $span );
-            }
-            return DAIA::Availability::date_or_datetime( $exp );
-        }
-    },
-);
-
-1;
-
 =head1 AUTHOR
 
-Jakob Voss C<< <jakob.voss@gbv.de> >>
+Jakob Voss
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+This software is copyright (c) 2011 by Jakob Voss.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.8.8 or, at
-your option, any later version of Perl 5 you may have available.
